/*
 * Created on May 10, 2005
 * 
 * This class is part of a Java implementation of the parse tree validation
 * technique proposed by Buehrer, Weide and Sivilotti.  
 * It is designed to eliminate SQL Injection
 * attacks in web applications.
 * 
 * Copyright 2005 The Ohio State University
 * This implementation makes use of the publically available SQL parser for Java,
 * ZQL (http://www.experlog.com/gibello/zql/). 
 * How To Use:
 *  (install ZQL)
 *  Connection Conn = SafeDriverManager.getConnection("jdbc:mysql://localhost/database1?user=user1&password=pass");
 * 	String query = SQLGuard.init() + "SELECT * FROM table where col1 = " +  SQLGuard.wrap(id) ;
 * 	Statement s2 = Conn.createStatement();
 * 	RS = s2.executeQuery(query);
 * 
 */
package edu.osu.cse.SQLprevention;

import java.sql.DriverManager;
import java.sql.Driver;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Enumeration;
import java.io.PrintWriter;

/**
 * SafeDriverManager provides a method getConnection(), which returns a SafeConnection.
 * It is part of a Java implementation of the parse tree validation
 * technique proposed by Buehrer, Weide and Sivilotti.  
 * It is designed to eliminate SQL Injection
 * attacks in web applications.
 * <BR><BR>
 * How To Use:<BR>
 *  (install ZQL)<BR>
 *  Connection Conn = SafeDriverManager.getConnection("jdbc:mysql://localhost/database1?user=user1&password=pass");<BR>
 * 	String query = SQLGuard.init() + "SELECT * FROM table where col1 = " +  SQLGuard.wrap(id) ;<BR>
 * 	Statement s2 = Conn.createStatement();<BR>
 * 	RS = s2.executeQuery(query);<BR>
 * <BR>
 * Copyright 2005 The Ohio State University<BR>
 * <BR>
 * @author Paolo Sivilotti.
 * 
 * @author Greg Buehrer.
 * 
 * @version 0.6, August 28, 2005.
 */
public class SafeDriverManager {

    /**
     * 
     */
    private SafeDriverManager() {
        // constructor not visible
    }

    /**
     * This is the only method which does anything different than the 
     * typical DriverManager class.  It is designed to create SafeConnections.
     * 
     * @param url
     * 		A connection string to a database
     * @return sc
     * 		A SafeConnection, an implementation of the Connection interface,
     * 			which provides a mechanism to eliminate SQL injection attacks.
     */
    public static Connection getConnection(String url) throws SQLException {
        Connection rc = DriverManager.getConnection(url);
        SafeConnection sc = new SafeConnection(rc);
        return sc;
    }
    
    
    /* (non-Javadoc)
     * @see java.sql.Driver#getDriver(String url)
     */
	static Driver getDriver(String url) throws Exception {
		return DriverManager.getDriver(url);
	}
	
    /* (non-Javadoc)
     * @see java.sql.Driver#getDrivers() 
     */
	static Enumeration getDrivers() 
	{
		return DriverManager.getDrivers(); 
	}
	
    /* (non-Javadoc)
     * @see java.sql.Driver#getLoginTimeout()
     */
	static int getLoginTimeout() 
	{
		return DriverManager.getLoginTimeout()  ;
	}
	
    /* (non-Javadoc)
     * @see java.sql.Driver#getLogWriter() 
     */
	static PrintWriter getLogWriter() 
	{
		return DriverManager.getLogWriter() ;
	}
	
    /* (non-Javadoc)
     * @see java.sql.Driver#println(String message) 
     */
	static void println(String message) 
	{
		DriverManager.println(message) ;
	}
	
    /* (non-Javadoc)
     * @see java.sql.Driver#registerDriver(Driver driver)
     */
	static void registerDriver(Driver driver) throws SQLException {
		DriverManager.registerDriver(driver) ;
	}
	
    /* (non-Javadoc)
     * @see java.sql.Driver#setLoginTimeout(int seconds) 
     */
	static void setLoginTimeout(int seconds) 
	{
		DriverManager.setLoginTimeout(seconds) ;
	}
	
    /* (non-Javadoc)
     * @see java.sql.Driver#setLogWriter(out) 
     */
	static void setLogWriter(PrintWriter out) 
	{
		DriverManager.setLogWriter(out) ;
	}

}
